@@ -55,7 +55,7 @@ KMime::ContentIndex::ContentIndex() : d(new Private)
 KMime::ContentIndex::ContentIndex(const QString &index) : d(new Private)
 {
     const QStringList l = index.split(QLatin1Char('.'));
-    foreach (const QString &s, l) {
+    for (const QString &s : l) {
         bool ok;
         unsigned int i = s.toUInt(&ok);
         if (!ok) {
@@ -101,7 +101,7 @@ QString KMime::ContentIndex::toString() const
     foreach (unsigned int i, d->index) {
         l.append(QString::number(i));
     }
-    return l.join(QStringLiteral("."));
+    return l.join(QLatin1Char('.'));
 }
 
 bool KMime::ContentIndex::operator ==(const ContentIndex &index) const
